@@ -121,10 +121,6 @@ void PmChart::setupDialogs(void)
 				this, SLOT(acceptEditTab()));
     connect(my.samples->buttonOk, SIGNAL(clicked()),
 				this, SLOT(acceptEditSamples()));
-    connect(my.newchart->buttonOk, SIGNAL(clicked()),
-				this, SLOT(acceptNewChart()));
-    connect(my.editchart->buttonOk, SIGNAL(clicked()),
-				this, SLOT(acceptEditChart()));
     connect(my.exporter->buttonOk, SIGNAL(clicked()),
 				this, SLOT(acceptExport()));
     my.dialogsSetup = true;
@@ -200,8 +196,10 @@ void PmChart::updateBackground(void)
 
 int PmChart::defaultFontSize()
 {
-#ifdef IS_DARWIN
+#if defined(IS_DARWIN)
     return 9;
+#elif defined(IS_MINGW)
+    return 8;
 #else
     return 7;
 #endif
@@ -213,6 +211,10 @@ void PmChart::updateHeight(int adjustment)
     int ideal = newSize.height() + adjustment;	// may be negative
     int sized = QApplication::desktop()->availableGeometry().height();
 
+    console->post(PmChart::DebugUi,
+	"upateHeight() oldsize h=%d,w=%d maximum=%d proposed=%d",
+	newSize.height(), newSize.width(), sized, ideal);
+
     if (ideal > sized)
 	ideal = sized;
     newSize.setHeight(ideal);
@@ -506,13 +508,18 @@ void PmChart::optionsNewPmchart()
     buddy->start("pmchart", arguments);
 }
 
-void PmChart::createNewChart(Chart::Style style)
+void PmChart::createNewChart()
 {
     setupDialogs();
-    my.newchart->reset(NULL, (int)style - 1, QString::null);
+    my.newchart->reset();
     my.newchart->show();
 }
 
+//
+// Note: Called from both Accept and OK on New Chart dialog
+// Must only called when the changes are definately going to
+// be applied, so all input validation must be done by now.
+//
 void PmChart::acceptNewChart()
 {
     bool yAutoScale;
@@ -529,6 +536,7 @@ void PmChart::acceptNewChart()
 	cp->changeTitle(newTitle, true);
     cp->setLegendVisible(my.newchart->legend());
     cp->setAntiAliasing(my.newchart->antiAliasing());
+    cp->setRateConvert(my.newchart->rateConvert());
     if (my.newchart->setupChartPlotsShortcut(cp) == false)
 	my.newchart->setupChartPlots(cp);
     my.newchart->scale(&yAutoScale, &yMin, &yMax);
@@ -539,35 +547,20 @@ void PmChart::acceptNewChart()
     activeGroup->setupWorldView();
     activeTab()->showGadgets();
 
-    // TODO: teardown TreeViews and free up memory (both?  chartList only?)
-    // TODO: might be an idea to keep available once its built, to optimise
-    // subsequent accesses to the metric selection process...
-
     enableUi();
 }
 
 void PmChart::fileNewChart()
 {
-    createNewChart(Chart::LineStyle);
+    createNewChart();
 }
 
 void PmChart::editChart()
 {
-    bool yAutoScale;
-    double yMin, yMax;
     Chart *cp = (Chart *)activeTab()->currentGadget();
 
     setupDialogs();
-    my.editchart->reset(cp, cp->style() - 1, cp->scheme());
-    my.editchart->titleLineEdit->setText(cp->title());
-    my.editchart->legendOn->setChecked(cp->legendVisible());
-    my.editchart->legendOff->setChecked(!cp->legendVisible());
-    my.editchart->antiAliasingOn->setChecked(cp->antiAliasing());
-    my.editchart->antiAliasingOff->setChecked(!cp->antiAliasing());
-    my.editchart->antiAliasingAuto->setChecked(false);
-    cp->scale(&yAutoScale, &yMin, &yMax);
-    my.editchart->setScale(yAutoScale, yMin, yMax);
-    my.editchart->setScheme(cp->scheme(), cp->sequence());
+    my.editchart->reset(cp);
     my.editchart->show();
 }
 
@@ -584,6 +577,7 @@ void PmChart::acceptEditChart()
 	cp->changeTitle(editTitle, true);
     cp->setLegendVisible(my.editchart->legend());
     cp->setAntiAliasing(my.editchart->antiAliasing());
+    cp->setRateConvert(my.editchart->rateConvert());
     my.editchart->scale(&yAutoScale, &yMin, &yMax);
     cp->setScale(yAutoScale, yMin, yMax);
     my.editchart->setupChartPlots(cp);
@@ -596,14 +590,6 @@ void PmChart::acceptEditChart()
     else
 	activeTab()->deleteGadget(cp);
 
-    // TODO: need a flag on "cp" that says "currently being edited" so
-    // the Chart Delete menu option doesn't shoot it down before we're
-    // done here.  Both Cancel and OK will need to clear that flag.
-
-    // TODO: teardown TreeViews and free up memory (both?  chartList only?)
-    // TODO: might be an idea to keep available once its built, to optimise
-    // subsequent accesses to the metric selection process...
-
     enableUi();
 }
 
